#!/bin/bash

wget https://github.com/Kitware/CMake/releases/download/v3.13.2/cmake-3.13.2-Linux-x86_64.sh
curl -O https://dbus.freedesktop.org/releases/dbus/dbus-1.12.16.tar.gz
wget https://github.com/openssl/openssl/archive/OpenSSL_1_1_1i.tar.gz
